=======
Credits
=======

Maintainers
-----------

* Mikołaj Rybiński <mikolaj.rybinski@id.ethz.ch>
* Henrik Menne <henrik.menne@eeh.ee.ethz.ch>
* Henning Janssen <janssen@eeh.ee.ethz.ch>
* Maria Del <maria.del@id.ethz.ch>
* Chi-Ching Hsu <hsu@eeh.ee.ethz.ch>

Authors
-------

* Mikołaj Rybiński <mikolaj.rybinski@id.ethz.ch>
* David Graber <dev@davidgraber.ch>
* Henrik Menne <henrik.menne@eeh.ee.ethz.ch>
* Alise Chachereau <chachereau@eeh.ee.ethz.ch>
* Henning Janssen <janssen@eeh.ee.ethz.ch>
* David Taylor <dtaylor@ethz.ch>
* Joseph Engelbrecht <engelbrecht@eeh.ee.ethz.ch>
* Chi-Ching Hsu <hsu@eeh.ee.ethz.ch>

Contributors
------------

* Luca Nembrini <lucane@student.ethz.ch>
* Maria Del <maria.del@id.ethz.ch>
* Raphael Faerber <raphael.faerber@eeh.ee.ethz.ch>
* Ruben Stadler <rstadler@student.ethz.ch>
* Hanut Vemulapalli <vemulapalli@eeh.ee.ethz.ch>
